==> elasticloadbalancingv2-1.4.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/elasticloadbalancingv2/IApplicationLoadBalancerTarget.java <==
package software.amazon.awscdk.services.elasticloadbalancingv2;

/**
 * Interface for constructs that can be targets of an application load balancer.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.3 (build 1b1062d)", date = "2019-08-14T08:23:50.804Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface IApplicationLoadBalancerTarget extends software.amazon.jsii.JsiiSerializable {
    /**
     * Attach load-balanced target to a TargetGroup.
     * 
     * May return JSON to directly add to the [Targets] list, or return undefined
     * if the target will register itself with the load balancer.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.services.elasticloadbalancingv2.LoadBalancerTargetProps attachToApplicationTargetGroup(final software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationTargetGroup targetGroup);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.elasticloadbalancingv2.IApplicationLoadBalancerTarget {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * Attach load-balanced target to a TargetGroup.
         * 
         * May return JSON to directly add to the [Targets] list, or return undefined
         * if the target will register itself with the load balancer.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.elasticloadbalancingv2.LoadBalancerTargetProps attachToApplicationTargetGroup(final software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationTargetGroup targetGroup) {
            return this.jsiiCall("attachToApplicationTargetGroup", software.amazon.awscdk.services.elasticloadbalancingv2.LoadBalancerTargetProps.class, new Object[] { java.util.Objects.requireNonNull(targetGroup, "targetGroup is required") });
        }
    }
}

==> elasticloadbalancingv2-1.5.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/elasticloadbalancingv2/IApplicationLoadBalancerTarget.java <==
package software.amazon.awscdk.services.elasticloadbalancingv2;

/**
 * Interface for constructs that can be targets of an application load balancer.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.15.1 (build ceff2ca)", date = "2019-08-21T10:55:00.810Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface IApplicationLoadBalancerTarget extends software.amazon.jsii.JsiiSerializable {
    /**
     * Attach load-balanced target to a TargetGroup.
     * 
     * May return JSON to directly add to the [Targets] list, or return undefined
     * if the target will register itself with the load balancer.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.services.elasticloadbalancingv2.LoadBalancerTargetProps attachToApplicationTargetGroup(final software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationTargetGroup targetGroup);


    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.elasticloadbalancingv2.IApplicationLoadBalancerTarget {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
        }

        /**
         * Attach load-balanced target to a TargetGroup.
         * 
         * May return JSON to directly add to the [Targets] list, or return undefined
         * if the target will register itself with the load balancer.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.elasticloadbalancingv2.LoadBalancerTargetProps attachToApplicationTargetGroup(final software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationTargetGroup targetGroup) {
            return this.jsiiCall("attachToApplicationTargetGroup", software.amazon.awscdk.services.elasticloadbalancingv2.LoadBalancerTargetProps.class, new Object[] { java.util.Objects.requireNonNull(targetGroup, "targetGroup is required") });
        }
    }
}
